@@ -10,12 +10,15 @@ import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_dynamodb._jsii
+import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kinesis._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_msk._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_s3_notifications._jsii
+import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sns_subscriptions._jsii
 import aws_cdk.aws_sqs._jsii
@@ -24,9 +27,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-lambda-event-sources",
-    "1.93.0",
+    "1.95.2",
     __name__[0:-6],
-    "aws-lambda-event-sources@1.93.0.jsii.tgz",
+    "aws-lambda-event-sources@1.95.2.jsii.tgz",
 )
 
 __all__ = [
